@@ -51,6 +51,9 @@ def get_date(current_date = datetime.now()):
         elif key == 'left': col -= 1
         elif key == 'right': col += 1
         elif key == 'enter':
+            input('skipping real key input')
+            sys.stdout.write("\033[F")
+            sys.stdout.write("\033[K")
             if row < 0:
                 if col == 1: date -= timedelta(1)
                 else: date += timedelta(31)
