@@ -2,9 +2,12 @@ import sys
 import keyboard as kb
 
 
-def select(array: list):
+def select(array: list, head: str=None, key=None):
+    if key and callable(key):
+        array = [key(x) for x in array]
     row = 0
     a_len = 7
+    if head: a_len = len(head)
     for x in array:
         if len(x) > a_len: a_len = len(x)
     a_len+=2
@@ -14,7 +17,7 @@ def select(array: list):
     free = a_len - 7
     left = free//2
     right = free - left
-    heat.append('│'+' '*left+'Select:'+' '*right+'│')
+    heat.append('│'+' '*left+(head if head else 'Select:')+' '*right+'│')
     heat.append('│'+'─'*a_len+'│')
 
     while True:
@@ -35,7 +38,7 @@ def select(array: list):
             print(row_data)
 
         key = kb.read_key()
-        assert key == kb.read_key()
+        kb.read_key()
 
         if key == 'up': row -= 1
         elif key == 'down': row += 1
